16.110. cdist-type__pf_apply(7) — cdist 4.11.0 documentation

# 16.110. cdist-type__pf_apply(7)

## 16.110.1. NAME

cdist-type__pf_apply - Apply pf(4) ruleset on *BSD

## 16.110.2. DESCRIPTION

This type is used on *BSD systems to manage the pf firewall's active ruleset.

## 16.110.3. REQUIRED PARAMETERS

NONE

## 16.110.4. OPTIONAL PARAMETERS

NONE

## 16.110.5. EXAMPLES

    # Modify the ruleset on $__target_host:
    __pf_ruleset --state present --source /my/pf/ruleset.conf
    require="__pf_ruleset" \
       __pf_apply

    # Remove the ruleset on $__target_host (implies disabling pf(4):
    __pf_ruleset --state absent
    require="__pf_ruleset" \
       __pf_apply

## 16.110.6. SEE ALSO

pf(4), cdist-type__pf_ruleset(7)

## 16.110.7. AUTHORS

Jake Guffey <jake.guffey--@--eprotex.com>

## 16.110.8. COPYING

Copyright (C) 2012 Jake Guffey. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.